:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _v0_6:

Version 0.6
===========

This release includes an enhancement mainly in the MultiViewDecisionTreeClassifier
and HonestForestClassifier, and a new generative model for the make_trunk_classification.

Changelog
---------

- |Enhancement| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now
  rounds up the number of features to split on to the nearest integer when
  applying ``max_features`` to each feature view, by `Adam Li`_ (:pr:`#183`).
- |Feature| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now
  supports an array passed in for ``max_features``, which applies a different
  max_features argument per view, by `Adam Li`_ (:pr:`#183`).
- |Fix| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now correctly
  handles the case where there is one feature view that is exhausted, and
  another that is not for ``apply_max_features_per_feature_set = False``,
  by `Adam Li`_ (:pr:`#183`).
- |Fix| ``treeple.stats.FeatureImportanceForestClassifier`` now correctly passes
  metric kwargs to the null distribution function, by `Adam Li`_ (:pr:`#183`).
- |Enhancement| :func:`treeple.datasets.make_trunk_classification` now
  has a generative model based on Trunk and banded covariance, :func:`treeple.datasets.approximate_clf_mutual_information` and
  :func:`treeple.datasets.approximate_clf_mutual_information_with_monte_carlo` to
  approximate mutual information either numerically or via Monte-Carlo, by `Adam Li`_ and `Haoyin Xu`_ (:pr:`#199`).
- |Enhancement| :class:`treeple.HonestForestClassifier` now has a fitted
  property ``oob_samples_``, which reproduces the sample indices per tree that is out
  of bag, by `Adam Li`_ (:pr:`#200`).
- |Enhancement| :class:`treeple.HonestForestClassifier` will allow one to bootstrap sample higher
  than the number of samples, controlled by the ``max_samples`` keyword argument by `Adam Li`_ (:pr:`#206`).
- |Feature| :class:`treeple.HonestForestClassifier` now allows one to specify
  the number of sub-samples to use for the honest trees without having
  to bootstrap sample. This is specified by the ``max_samples`` parameter.
  By `Adam Li`_ (:pr:`#210`)

Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_
* `Haoyin Xu`_
